PRAW: The Python Reddit API Wrapper
===================================

PRAW's documentation is organized into the following sections:

* :ref:`getting_started`
* :ref:`code_overview`
* :ref:`tutorial`
* :ref:`package_info`

Documentation Conventions
-------------------------

Unless otherwise mentioned, all examples in this document assume the use of a
**script** application. See :ref:`oauth` for information on using **installed**
applications and **web** applications.

.. _getting_started:
.. toctree::
   :maxdepth: 1
   :caption: Getting Started

   getting_started/quick_start
   getting_started/installation
   getting_started/authentication
   getting_started/configuration
   getting_started/multiple_instances
   getting_started/logging
   getting_started/faq

.. _code_overview:
.. toctree::
   :maxdepth: 1
   :caption: Code Overview

   code_overview/reddit_instance
   code_overview/praw_models
   code_overview/exceptions
   code_overview/other

.. _tutorial:
.. toctree::
   :maxdepth: 1
   :caption: Tutorials

   tutorials/comments.rst
   tutorials/refresh_token.rst
   tutorials/reply_bot.rst

.. _package_info:
.. toctree::
   :maxdepth: 1
   :caption: Package Info

   package_info/change_log
   package_info/contributing
   package_info/glossary
   package_info/praw7_migration
   package_info/references

.. toctree::
   :hidden:

   genindex
